@@ -1,5 +1,4 @@
 import unittest
-from mindsdb_native import F
 from common import DB_CREDENTIALS, break_dataset
 
 
@@ -30,8 +29,6 @@ class TestMYSQL(unittest.TestCase):
 
         assert len(mysql_ds) <= LIMIT
 
-        F.analyse_dataset(mysql_ds)
-
         # Our SQL parsing fails here, test if we're still able to filter via the dataframe fallback
         for val in mysql_ds.filter([['sex', 'like','fem']])['sex']:
             assert val == 'female'
